package de.hpi.imdbsuche;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.ResultSetMetaData;
import java.sql.SQLException;
import java.sql.Statement;

import de.hpi.imdbsuche.database.DatabaseServer;
import de.hpi.imdbsuche.entities.imdb.Actor;

/**
 * A class to experiment with different JDBC access methods in Java.
 */
public class ImdbSuche {

	public static void main(String[] args) {

		try (DatabaseServer server = new DatabaseServer("db2db1", "db2inst1", "ws2011")) {
			server.loadData();

			String databaseUrl = server.getDatabaseUrl();
			String username = server.getUsername();
			String password = server.getPassword();
			
			readActors1(databaseUrl, username, password);
			
			System.out.println();
			
			readActors2(databaseUrl, username, password);

			System.out.println();
			
			count(databaseUrl, "movie", username, password);
			count(databaseUrl, "actor", username, password);
			count(databaseUrl, "actress", username, password);
			count(databaseUrl, "producer", username, password);
			count(databaseUrl, "genre", username, password);
			
		} catch (SQLException e) {
			e.printStackTrace();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	private static void readActors1(String databaseUrl, String username, String password) {

		try (Connection con = DriverManager.getConnection(databaseUrl, username, password)) {

			String sql = "SELECT * FROM actor LIMIT 10";

			try (PreparedStatement stmt = con.prepareStatement(sql); ResultSet rs = stmt.executeQuery()) {

				ResultSetMetaData metaData = rs.getMetaData();
				int numColumns = metaData.getColumnCount();

				while (rs.next()) {
					System.out.print("Actor[");
					for (int attribute = 1; attribute < numColumns; attribute++)
						System.out.print(rs.getObject(attribute) + ", ");
					System.out.println(rs.getObject(numColumns));
				}
			}

		} catch (SQLException e) {
			e.printStackTrace();
		}
	}
	
	private static void readActors2(String databaseUrl, String username, String password) {

		try (Connection con = DriverManager.getConnection(databaseUrl, username, password)) {

			String sql = "SELECT * FROM actor LIMIT 10";

			try (PreparedStatement stmt = con.prepareStatement(sql); ResultSet rs = stmt.executeQuery()) {

				while (rs.next())
					System.out.println(new Actor(rs));
			}

		} catch (SQLException e) {
			e.printStackTrace();
		}
	}
	
	private static void count(String databaseUrl, String table, String username, String password) {

		try (Connection con = DriverManager.getConnection(databaseUrl, username, password)) {

			String sql = "SELECT count(*) FROM " + table;

			try (Statement stmt = con.createStatement(); ResultSet rs = stmt.executeQuery(sql)) {

				rs.next();

				System.out.println(sql);
				System.out.println(rs.getInt(1));
				System.out.println();
			}

		} catch (SQLException e) {
			e.printStackTrace();
		}
	}

}
