package de.hpi.imdbsuche.entities.imdb;

import java.sql.ResultSet;
import java.sql.SQLException;

import de.hpi.imdbsuche.entities.DBEntity;

public class Actor implements DBEntity {

	public static final String TABLE_NAME = "actor";
	
	public static final String SQL_CREATE_TABLE = "CREATE TABLE actor ("
													+ "id INTEGER PRIMARY KEY,"
													+ "name VARCHAR(127),"
													+ "movie_id VARCHAR(127),"
													+ "role VARCHAR(127),"
													+ "xorder INTEGER)";
	
	public static final String SQL_INSERT_INTO = "INSERT INTO actor(id,name,movie_id,role,xorder) VALUES(?,?,?,?,?)";

	private final int id;
	
	private final String name;
	
	private final String movieId;
	
	private final String role;
	
	private final int order;
	
	public int getId() {
		return this.id;
	}

	public String getName() {
		return this.name;
	}

	public String getMovieId() {
		return this.movieId;
	}

	public String getRole() {
		return this.role;
	}

	public int getOrder() {
		return this.order;
	}

	@Override
	public String getTableName() {
		return TABLE_NAME;
	}

	@Override
	public String getCreateTableSql() {
		return SQL_CREATE_TABLE;
	}

	@Override
	public String getInsertIntoSql() {
		return SQL_INSERT_INTO;
	}

	public Actor(ResultSet rs) throws SQLException {
		this(	rs.getInt("id"), 
				rs.getString("name"), 
				rs.getString("movie_id"), 
				rs.getString("role"), 
				rs.getInt("xorder"));
	}
	
	public Actor(int id, String name, String movieId, String role, int order) {
		this.id = id;
		this.name = name;
		this.movieId = movieId;
		this.role = role;
		this.order = order;
	}
	
	public Actor() {
		this.id = 0;
		this.name = null;
		this.movieId = null;
		this.role = null;
		this.order = 0;
	}

	@Override
	public String toString() {
		return "Actor[" + this.id + ", " + this.name + ", " + this.movieId + ", " + this.role + ", " + this.order + "]";
	}
}
